class Netfira::InstallerGenerator
  class Binary::Signcode < Binary

    def self.bin_files; %w[osslsigncode signcode] end

    attr_accessor :spc_path, :key_path, :description, :url, :source_path, :target_path

    def command
      send :"#{self.class.bin_file}_cmd"
    end

    private

    # See http://development.adaptris.net/users/lchan/blog/2013/06/07/signing-windows-installers-on-linux/

    def osslsigncode_cmd
      parts = [
          'osslsigncode',
          '-spc', esc(spc_path),
          '-key', esc(key_path),
          '-n', esc(description || 'Netfira'),
          '-i', esc(url || 'http://netfira.com'),
          '-t http://timestamp.verisign.com/scripts/timstamp.dll',
          '-in', esc(source_path),
          '-out', esc(target_path)
      ]
      parts.join ' '
    end

    # From Amel's rendition:
    # $signCommand = "signcode -spc {$certFileBase}authenticode.spc -v {$certFileBase}authenticode.pvk -a sha1 -$ commercial -n Netfira ";
    # $signCommand .= "-i http://netfira.com -t http://timestamp.verisign.com/scripts/timstamp.dll -tr 10 ".$fileName;
    #
    # See http://manpages.ubuntu.com/manpages/precise/man1/signcode.1.html

    def signcode_cmd
      parts = [
          'cp', esc(source_path), esc(target_path), '&&',
          'signcode',
          '-spc', esc(spc_path),
          '-v', esc(key_path),
          '-a sha1',                # Hash algorithm
          '-$ commercial',          # Publisher information
          '-n', esc(description || 'Netfira'),
          '-i', esc(url || 'http://netfira.com'),
          '-t http://timestamp.verisign.com/scripts/timstamp.dll',
          '-tr 3 -tw 5',            # Try timestamping 3 times, 5 seconds apart
          esc(target_path)
      ]
      parts.join ' '
    end

  end
end
